@@ -32,6 +32,9 @@ FAILEDOPERATION_ERRORCLUSTERSTATE = 'FailedOperation.ErrorClusterState'
 # No credit card or PayPal account is linked to the current account. Unable to make a payment.
 FAILEDOPERATION_NOPAYMENT = 'FailedOperation.NoPayment'
 
+# Unverified user.
+FAILEDOPERATION_NOTAUTHENTICATED = 'FailedOperation.NotAuthenticated'
+
 # Cannot adjust the node configuration and disk capacity reversely.
 FAILEDOPERATION_UNSUPPORTREVERSEREGULATIONNODETYPEANDDISK = 'FailedOperation.UnsupportReverseRegulationNodeTypeAndDisk'
 
